==> cubao_headers-0.0.6.tar.gz: cubao_headers-0.0.6/setup.py <==
#!/usr/bin/env python3
from setuptools import setup, find_packages

name = "cubao_headers"
version = "0.0.6"

pattern = ["*"]

setup(
    name=name,
    version=version,
    packages=[f"{name}",
        f"{name}.include",
        f"{name}.include.Eigen",
        f"{name}.include.Eigen.src",
        f"{name}.include.Eigen.src.Cholesky",
        f"{name}.include.Eigen.src.CholmodSupport",
        f"{name}.include.Eigen.src.Core",
        f"{name}.include.Eigen.src.Core.arch",
        f"{name}.include.Eigen.src.Core.arch.AVX",
        f"{name}.include.Eigen.src.Core.arch.AVX512",
        f"{name}.include.Eigen.src.Core.arch.AltiVec",
        f"{name}.include.Eigen.src.Core.arch.CUDA",
        f"{name}.include.Eigen.src.Core.arch.Default",
        f"{name}.include.Eigen.src.Core.arch.GPU",
        f"{name}.include.Eigen.src.Core.arch.HIP",
        f"{name}.include.Eigen.src.Core.arch.HIP.hcc",
        f"{name}.include.Eigen.src.Core.arch.MSA",
        f"{name}.include.Eigen.src.Core.arch.NEON",
        f"{name}.include.Eigen.src.Core.arch.SSE",
        f"{name}.include.Eigen.src.Core.arch.SVE",
        f"{name}.include.Eigen.src.Core.arch.SYCL",
        f"{name}.include.Eigen.src.Core.arch.ZVector",
        f"{name}.include.Eigen.src.Core.functors",
        f"{name}.include.Eigen.src.Core.products",
        f"{name}.include.Eigen.src.Core.util",
        f"{name}.include.Eigen.src.Eigenvalues",
        f"{name}.include.Eigen.src.Geometry",
        f"{name}.include.Eigen.src.Geometry.arch",
        f"{name}.include.Eigen.src.Householder",
        f"{name}.include.Eigen.src.IterativeLinearSolvers",
        f"{name}.include.Eigen.src.Jacobi",
        f"{name}.include.Eigen.src.KLUSupport",
        f"{name}.include.Eigen.src.LU",
        f"{name}.include.Eigen.src.LU.arch",
        f"{name}.include.Eigen.src.MetisSupport",
        f"{name}.include.Eigen.src.OrderingMethods",
        f"{name}.include.Eigen.src.PaStiXSupport",
        f"{name}.include.Eigen.src.PardisoSupport",
        f"{name}.include.Eigen.src.QR",
        f"{name}.include.Eigen.src.SPQRSupport",
        f"{name}.include.Eigen.src.SVD",
        f"{name}.include.Eigen.src.SparseCholesky",
        f"{name}.include.Eigen.src.SparseCore",
        f"{name}.include.Eigen.src.SparseLU",
        f"{name}.include.Eigen.src.SparseQR",
        f"{name}.include.Eigen.src.StlSupport",
        f"{name}.include.Eigen.src.SuperLUSupport",
        f"{name}.include.Eigen.src.UmfPackSupport",
        f"{name}.include.Eigen.src.misc",
        f"{name}.include.Eigen.src.plugins",
        f"{name}.include.NumCpp",
        f"{name}.include.NumCpp.Coordinates",
        f"{name}.include.NumCpp.Core",
        f"{name}.include.NumCpp.Core.Internal",
        f"{name}.include.NumCpp.Filter",
        f"{name}.include.NumCpp.Filter.Boundaries",
        f"{name}.include.NumCpp.Filter.Boundaries.Boundaries1d",
        f"{name}.include.NumCpp.Filter.Boundaries.Boundaries2d",
        f"{name}.include.NumCpp.Filter.Filters",
        f"{name}.include.NumCpp.Filter.Filters.Filters1d",
        f"{name}.include.NumCpp.Filter.Filters.Filters2d",
        f"{name}.include.NumCpp.Functions",
        f"{name}.include.NumCpp.ImageProcessing",
        f"{name}.include.NumCpp.Integrate",
        f"{name}.include.NumCpp.Linalg",
        f"{name}.include.NumCpp.Linalg.svd",
        f"{name}.include.NumCpp.NdArray",
        f"{name}.include.NumCpp.Polynomial",
        f"{name}.include.NumCpp.PythonInterface",
        f"{name}.include.NumCpp.Random",
        f"{name}.include.NumCpp.Roots",
        f"{name}.include.NumCpp.Rotations",
        f"{name}.include.NumCpp.Special",
        f"{name}.include.NumCpp.Utils",
        f"{name}.include.NumCpp.Vector",
        f"{name}.include.ankerl",
        f"{name}.include.bvh",
        f"{name}.include.cista",
        f"{name}.include.cista.containers",
        f"{name}.include.cista.endian",
        f"{name}.include.cista.reflection",
        f"{name}.include.cista.targets",
        f"{name}.include.cista.type_hash",
        f"{name}.include.cubao",
        f"{name}.include.fplus",
        f"{name}.include.frozen",
        f"{name}.include.frozen.bits",
        f"{name}.include.gzip",
        f"{name}.include.igl",
        f"{name}.include.igl.embree",
        f"{name}.include.igl.matlab",
        f"{name}.include.igl.mosek",
        f"{name}.include.igl.opengl",
        f"{name}.include.igl.opengl.glfw",
        f"{name}.include.igl.opengl.glfw.imgui",
        f"{name}.include.igl.opengl.stb",
        f"{name}.include.igl.png",
        f"{name}.include.igl.predicates",
        f"{name}.include.igl.spectra",
        f"{name}.include.igl.stb",
        f"{name}.include.igl.triangle",
        f"{name}.include.igl.xml",
        f"{name}.include.jni",
        f"{name}.include.mapbox",
        f"{name}.include.mapbox.geojson",
        f"{name}.include.mapbox.geojsonvt",
        f"{name}.include.mapbox.geometry",
        f"{name}.include.mapbox.geometry.wagyu",
        f"{name}.include.mio",
        f"{name}.include.nlohmann",
        f"{name}.include.parallel_hashmap",
        f"{name}.include.protozero",
        f"{name}.include.rapidjson",
        f"{name}.include.rapidjson.error",
        f"{name}.include.rapidjson.internal",
        f"{name}.include.rapidjson.msinttypes",
        f"{name}.include.spdlog",
        f"{name}.include.spdlog.cfg",
        f"{name}.include.spdlog.details",
        f"{name}.include.spdlog.fmt",
        f"{name}.include.spdlog.fmt.bundled",
        f"{name}.include.spdlog.sinks",
        f"{name}.include.taskflow",
        f"{name}.include.taskflow.algorithm",
        f"{name}.include.taskflow.core",
        f"{name}.include.taskflow.cuda",
        f"{name}.include.taskflow.cuda.algorithm",
        f"{name}.include.taskflow.dsl",
        f"{name}.include.taskflow.sycl",
        f"{name}.include.taskflow.sycl.algorithm",
        f"{name}.include.taskflow.utility",
        f"{name}.include.tl",
        f"{name}.include.tsl"],
    package_data={
        f"{name}.include": pattern,
        f"{name}.include.Eigen": pattern,
        f"{name}.include.Eigen.src": pattern,
        f"{name}.include.Eigen.src.Cholesky": pattern,
        f"{name}.include.Eigen.src.CholmodSupport": pattern,
        f"{name}.include.Eigen.src.Core": pattern,
        f"{name}.include.Eigen.src.Core.arch": pattern,
        f"{name}.include.Eigen.src.Core.arch.AVX": pattern,
        f"{name}.include.Eigen.src.Core.arch.AVX512": pattern,
        f"{name}.include.Eigen.src.Core.arch.AltiVec": pattern,
        f"{name}.include.Eigen.src.Core.arch.CUDA": pattern,
        f"{name}.include.Eigen.src.Core.arch.Default": pattern,
        f"{name}.include.Eigen.src.Core.arch.GPU": pattern,
        f"{name}.include.Eigen.src.Core.arch.HIP": pattern,
        f"{name}.include.Eigen.src.Core.arch.HIP.hcc": pattern,
        f"{name}.include.Eigen.src.Core.arch.MSA": pattern,
        f"{name}.include.Eigen.src.Core.arch.NEON": pattern,
        f"{name}.include.Eigen.src.Core.arch.SSE": pattern,
        f"{name}.include.Eigen.src.Core.arch.SVE": pattern,
        f"{name}.include.Eigen.src.Core.arch.SYCL": pattern,
        f"{name}.include.Eigen.src.Core.arch.ZVector": pattern,
        f"{name}.include.Eigen.src.Core.functors": pattern,
        f"{name}.include.Eigen.src.Core.products": pattern,
        f"{name}.include.Eigen.src.Core.util": pattern,
        f"{name}.include.Eigen.src.Eigenvalues": pattern,
        f"{name}.include.Eigen.src.Geometry": pattern,
        f"{name}.include.Eigen.src.Geometry.arch": pattern,
        f"{name}.include.Eigen.src.Householder": pattern,
        f"{name}.include.Eigen.src.IterativeLinearSolvers": pattern,
        f"{name}.include.Eigen.src.Jacobi": pattern,
        f"{name}.include.Eigen.src.KLUSupport": pattern,
        f"{name}.include.Eigen.src.LU": pattern,
        f"{name}.include.Eigen.src.LU.arch": pattern,
        f"{name}.include.Eigen.src.MetisSupport": pattern,
        f"{name}.include.Eigen.src.OrderingMethods": pattern,
        f"{name}.include.Eigen.src.PaStiXSupport": pattern,
        f"{name}.include.Eigen.src.PardisoSupport": pattern,
        f"{name}.include.Eigen.src.QR": pattern,
        f"{name}.include.Eigen.src.SPQRSupport": pattern,
        f"{name}.include.Eigen.src.SVD": pattern,
        f"{name}.include.Eigen.src.SparseCholesky": pattern,
        f"{name}.include.Eigen.src.SparseCore": pattern,
        f"{name}.include.Eigen.src.SparseLU": pattern,
        f"{name}.include.Eigen.src.SparseQR": pattern,
        f"{name}.include.Eigen.src.StlSupport": pattern,
        f"{name}.include.Eigen.src.SuperLUSupport": pattern,
        f"{name}.include.Eigen.src.UmfPackSupport": pattern,
        f"{name}.include.Eigen.src.misc": pattern,
        f"{name}.include.Eigen.src.plugins": pattern,
        f"{name}.include.NumCpp": pattern,
        f"{name}.include.NumCpp.Coordinates": pattern,
        f"{name}.include.NumCpp.Core": pattern,
        f"{name}.include.NumCpp.Core.Internal": pattern,
        f"{name}.include.NumCpp.Filter": pattern,
        f"{name}.include.NumCpp.Filter.Boundaries": pattern,
        f"{name}.include.NumCpp.Filter.Boundaries.Boundaries1d": pattern,
        f"{name}.include.NumCpp.Filter.Boundaries.Boundaries2d": pattern,
        f"{name}.include.NumCpp.Filter.Filters": pattern,
        f"{name}.include.NumCpp.Filter.Filters.Filters1d": pattern,
        f"{name}.include.NumCpp.Filter.Filters.Filters2d": pattern,
        f"{name}.include.NumCpp.Functions": pattern,
        f"{name}.include.NumCpp.ImageProcessing": pattern,
        f"{name}.include.NumCpp.Integrate": pattern,
        f"{name}.include.NumCpp.Linalg": pattern,
        f"{name}.include.NumCpp.Linalg.svd": pattern,
        f"{name}.include.NumCpp.NdArray": pattern,
        f"{name}.include.NumCpp.Polynomial": pattern,
        f"{name}.include.NumCpp.PythonInterface": pattern,
        f"{name}.include.NumCpp.Random": pattern,
        f"{name}.include.NumCpp.Roots": pattern,
        f"{name}.include.NumCpp.Rotations": pattern,
        f"{name}.include.NumCpp.Special": pattern,
        f"{name}.include.NumCpp.Utils": pattern,
        f"{name}.include.NumCpp.Vector": pattern,
        f"{name}.include.ankerl": pattern,
        f"{name}.include.bvh": pattern,
        f"{name}.include.cista": pattern,
        f"{name}.include.cista.containers": pattern,
        f"{name}.include.cista.endian": pattern,
        f"{name}.include.cista.reflection": pattern,
        f"{name}.include.cista.targets": pattern,
        f"{name}.include.cista.type_hash": pattern,
        f"{name}.include.cubao": pattern,
        f"{name}.include.fplus": pattern,
        f"{name}.include.frozen": pattern,
        f"{name}.include.frozen.bits": pattern,
        f"{name}.include.gzip": pattern,
        f"{name}.include.igl": pattern,
        f"{name}.include.igl.embree": pattern,
        f"{name}.include.igl.matlab": pattern,
        f"{name}.include.igl.mosek": pattern,
        f"{name}.include.igl.opengl": pattern,
        f"{name}.include.igl.opengl.glfw": pattern,
        f"{name}.include.igl.opengl.glfw.imgui": pattern,
        f"{name}.include.igl.opengl.stb": pattern,
        f"{name}.include.igl.png": pattern,
        f"{name}.include.igl.predicates": pattern,
        f"{name}.include.igl.spectra": pattern,
        f"{name}.include.igl.stb": pattern,
        f"{name}.include.igl.triangle": pattern,
        f"{name}.include.igl.xml": pattern,
        f"{name}.include.jni": pattern,
        f"{name}.include.mapbox": pattern,
        f"{name}.include.mapbox.geojson": pattern,
        f"{name}.include.mapbox.geojsonvt": pattern,
        f"{name}.include.mapbox.geometry": pattern,
        f"{name}.include.mapbox.geometry.wagyu": pattern,
        f"{name}.include.mio": pattern,
        f"{name}.include.nlohmann": pattern,
        f"{name}.include.parallel_hashmap": pattern,
        f"{name}.include.protozero": pattern,
        f"{name}.include.rapidjson": pattern,
        f"{name}.include.rapidjson.error": pattern,
        f"{name}.include.rapidjson.internal": pattern,
        f"{name}.include.rapidjson.msinttypes": pattern,
        f"{name}.include.spdlog": pattern,
        f"{name}.include.spdlog.cfg": pattern,
        f"{name}.include.spdlog.details": pattern,
        f"{name}.include.spdlog.fmt": pattern,
        f"{name}.include.spdlog.fmt.bundled": pattern,
        f"{name}.include.spdlog.sinks": pattern,
        f"{name}.include.taskflow": pattern,
        f"{name}.include.taskflow.algorithm": pattern,
        f"{name}.include.taskflow.core": pattern,
        f"{name}.include.taskflow.cuda": pattern,
        f"{name}.include.taskflow.cuda.algorithm": pattern,
        f"{name}.include.taskflow.dsl": pattern,
        f"{name}.include.taskflow.sycl": pattern,
        f"{name}.include.taskflow.sycl.algorithm": pattern,
        f"{name}.include.taskflow.utility": pattern,
        f"{name}.include.tl": pattern,
        f"{name}.include.tsl": pattern,
    },
)

==> cubao_headers-0.0.7.tar.gz: cubao_headers-0.0.7/setup.py <==
#!/usr/bin/env python3
from setuptools import setup, find_packages

name = "cubao_headers"
version = "0.0.7"

pattern = ["*"]

setup(
    name=name,
    version=version,
    packages=[f"{name}",
        f"{name}.include",
        f"{name}.include.Eigen",
        f"{name}.include.Eigen.src",
        f"{name}.include.Eigen.src.Cholesky",
        f"{name}.include.Eigen.src.CholmodSupport",
        f"{name}.include.Eigen.src.Core",
        f"{name}.include.Eigen.src.Core.arch",
        f"{name}.include.Eigen.src.Core.arch.AVX",
        f"{name}.include.Eigen.src.Core.arch.AVX512",
        f"{name}.include.Eigen.src.Core.arch.AltiVec",
        f"{name}.include.Eigen.src.Core.arch.CUDA",
        f"{name}.include.Eigen.src.Core.arch.Default",
        f"{name}.include.Eigen.src.Core.arch.GPU",
        f"{name}.include.Eigen.src.Core.arch.HIP",
        f"{name}.include.Eigen.src.Core.arch.HIP.hcc",
        f"{name}.include.Eigen.src.Core.arch.MSA",
        f"{name}.include.Eigen.src.Core.arch.NEON",
        f"{name}.include.Eigen.src.Core.arch.SSE",
        f"{name}.include.Eigen.src.Core.arch.SVE",
        f"{name}.include.Eigen.src.Core.arch.SYCL",
        f"{name}.include.Eigen.src.Core.arch.ZVector",
        f"{name}.include.Eigen.src.Core.functors",
        f"{name}.include.Eigen.src.Core.products",
        f"{name}.include.Eigen.src.Core.util",
        f"{name}.include.Eigen.src.Eigenvalues",
        f"{name}.include.Eigen.src.Geometry",
        f"{name}.include.Eigen.src.Geometry.arch",
        f"{name}.include.Eigen.src.Householder",
        f"{name}.include.Eigen.src.IterativeLinearSolvers",
        f"{name}.include.Eigen.src.Jacobi",
        f"{name}.include.Eigen.src.KLUSupport",
        f"{name}.include.Eigen.src.LU",
        f"{name}.include.Eigen.src.LU.arch",
        f"{name}.include.Eigen.src.MetisSupport",
        f"{name}.include.Eigen.src.OrderingMethods",
        f"{name}.include.Eigen.src.PaStiXSupport",
        f"{name}.include.Eigen.src.PardisoSupport",
        f"{name}.include.Eigen.src.QR",
        f"{name}.include.Eigen.src.SPQRSupport",
        f"{name}.include.Eigen.src.SVD",
        f"{name}.include.Eigen.src.SparseCholesky",
        f"{name}.include.Eigen.src.SparseCore",
        f"{name}.include.Eigen.src.SparseLU",
        f"{name}.include.Eigen.src.SparseQR",
        f"{name}.include.Eigen.src.StlSupport",
        f"{name}.include.Eigen.src.SuperLUSupport",
        f"{name}.include.Eigen.src.UmfPackSupport",
        f"{name}.include.Eigen.src.misc",
        f"{name}.include.Eigen.src.plugins",
        f"{name}.include.ankerl",
        f"{name}.include.bvh",
        f"{name}.include.bvh.v2",
        f"{name}.include.bvh.v2.c_api",
        f"{name}.include.cista",
        f"{name}.include.cista.containers",
        f"{name}.include.cista.endian",
        f"{name}.include.cista.reflection",
        f"{name}.include.cista.targets",
        f"{name}.include.cista.type_hash",
        f"{name}.include.cubao",
        f"{name}.include.fplus",
        f"{name}.include.frozen",
        f"{name}.include.frozen.bits",
        f"{name}.include.gzip",
        f"{name}.include.igl",
        f"{name}.include.igl.mosek",
        f"{name}.include.igl.png",
        f"{name}.include.igl.predicates",
        f"{name}.include.igl.spectra",
        f"{name}.include.igl.stb",
        f"{name}.include.igl.triangle",
        f"{name}.include.jni",
        f"{name}.include.mapbox",
        f"{name}.include.mapbox.geojson",
        f"{name}.include.mapbox.geojsonvt",
        f"{name}.include.mapbox.geometry",
        f"{name}.include.mapbox.geometry.wagyu",
        f"{name}.include.mio",
        f"{name}.include.nlohmann",
        f"{name}.include.parallel_hashmap",
        f"{name}.include.protozero",
        f"{name}.include.rapidjson",
        f"{name}.include.rapidjson.error",
        f"{name}.include.rapidjson.internal",
        f"{name}.include.rapidjson.msinttypes",
        f"{name}.include.spdlog",
        f"{name}.include.spdlog.cfg",
        f"{name}.include.spdlog.details",
        f"{name}.include.spdlog.fmt",
        f"{name}.include.spdlog.fmt.bundled",
        f"{name}.include.spdlog.sinks",
        f"{name}.include.taskflow",
        f"{name}.include.taskflow.algorithm",
        f"{name}.include.taskflow.core",
        f"{name}.include.taskflow.cuda",
        f"{name}.include.taskflow.cuda.algorithm",
        f"{name}.include.taskflow.dsl",
        f"{name}.include.taskflow.sycl",
        f"{name}.include.taskflow.sycl.algorithm",
        f"{name}.include.taskflow.utility",
        f"{name}.include.tl",
        f"{name}.include.tsl"],
    package_data={
        f"{name}.include": pattern,
        f"{name}.include.Eigen": pattern,
        f"{name}.include.Eigen.src": pattern,
        f"{name}.include.Eigen.src.Cholesky": pattern,
        f"{name}.include.Eigen.src.CholmodSupport": pattern,
        f"{name}.include.Eigen.src.Core": pattern,
        f"{name}.include.Eigen.src.Core.arch": pattern,
        f"{name}.include.Eigen.src.Core.arch.AVX": pattern,
        f"{name}.include.Eigen.src.Core.arch.AVX512": pattern,
        f"{name}.include.Eigen.src.Core.arch.AltiVec": pattern,
        f"{name}.include.Eigen.src.Core.arch.CUDA": pattern,
        f"{name}.include.Eigen.src.Core.arch.Default": pattern,
        f"{name}.include.Eigen.src.Core.arch.GPU": pattern,
        f"{name}.include.Eigen.src.Core.arch.HIP": pattern,
        f"{name}.include.Eigen.src.Core.arch.HIP.hcc": pattern,
        f"{name}.include.Eigen.src.Core.arch.MSA": pattern,
        f"{name}.include.Eigen.src.Core.arch.NEON": pattern,
        f"{name}.include.Eigen.src.Core.arch.SSE": pattern,
        f"{name}.include.Eigen.src.Core.arch.SVE": pattern,
        f"{name}.include.Eigen.src.Core.arch.SYCL": pattern,
        f"{name}.include.Eigen.src.Core.arch.ZVector": pattern,
        f"{name}.include.Eigen.src.Core.functors": pattern,
        f"{name}.include.Eigen.src.Core.products": pattern,
        f"{name}.include.Eigen.src.Core.util": pattern,
        f"{name}.include.Eigen.src.Eigenvalues": pattern,
        f"{name}.include.Eigen.src.Geometry": pattern,
        f"{name}.include.Eigen.src.Geometry.arch": pattern,
        f"{name}.include.Eigen.src.Householder": pattern,
        f"{name}.include.Eigen.src.IterativeLinearSolvers": pattern,
        f"{name}.include.Eigen.src.Jacobi": pattern,
        f"{name}.include.Eigen.src.KLUSupport": pattern,
        f"{name}.include.Eigen.src.LU": pattern,
        f"{name}.include.Eigen.src.LU.arch": pattern,
        f"{name}.include.Eigen.src.MetisSupport": pattern,
        f"{name}.include.Eigen.src.OrderingMethods": pattern,
        f"{name}.include.Eigen.src.PaStiXSupport": pattern,
        f"{name}.include.Eigen.src.PardisoSupport": pattern,
        f"{name}.include.Eigen.src.QR": pattern,
        f"{name}.include.Eigen.src.SPQRSupport": pattern,
        f"{name}.include.Eigen.src.SVD": pattern,
        f"{name}.include.Eigen.src.SparseCholesky": pattern,
        f"{name}.include.Eigen.src.SparseCore": pattern,
        f"{name}.include.Eigen.src.SparseLU": pattern,
        f"{name}.include.Eigen.src.SparseQR": pattern,
        f"{name}.include.Eigen.src.StlSupport": pattern,
        f"{name}.include.Eigen.src.SuperLUSupport": pattern,
        f"{name}.include.Eigen.src.UmfPackSupport": pattern,
        f"{name}.include.Eigen.src.misc": pattern,
        f"{name}.include.Eigen.src.plugins": pattern,
        f"{name}.include.ankerl": pattern,
        f"{name}.include.bvh": pattern,
        f"{name}.include.bvh.v2": pattern,
        f"{name}.include.bvh.v2.c_api": pattern,
        f"{name}.include.cista": pattern,
        f"{name}.include.cista.containers": pattern,
        f"{name}.include.cista.endian": pattern,
        f"{name}.include.cista.reflection": pattern,
        f"{name}.include.cista.targets": pattern,
        f"{name}.include.cista.type_hash": pattern,
        f"{name}.include.cubao": pattern,
        f"{name}.include.fplus": pattern,
        f"{name}.include.frozen": pattern,
        f"{name}.include.frozen.bits": pattern,
        f"{name}.include.gzip": pattern,
        f"{name}.include.igl": pattern,
        f"{name}.include.igl.mosek": pattern,
        f"{name}.include.igl.png": pattern,
        f"{name}.include.igl.predicates": pattern,
        f"{name}.include.igl.spectra": pattern,
        f"{name}.include.igl.stb": pattern,
        f"{name}.include.igl.triangle": pattern,
        f"{name}.include.jni": pattern,
        f"{name}.include.mapbox": pattern,
        f"{name}.include.mapbox.geojson": pattern,
        f"{name}.include.mapbox.geojsonvt": pattern,
        f"{name}.include.mapbox.geometry": pattern,
        f"{name}.include.mapbox.geometry.wagyu": pattern,
        f"{name}.include.mio": pattern,
        f"{name}.include.nlohmann": pattern,
        f"{name}.include.parallel_hashmap": pattern,
        f"{name}.include.protozero": pattern,
        f"{name}.include.rapidjson": pattern,
        f"{name}.include.rapidjson.error": pattern,
        f"{name}.include.rapidjson.internal": pattern,
        f"{name}.include.rapidjson.msinttypes": pattern,
        f"{name}.include.spdlog": pattern,
        f"{name}.include.spdlog.cfg": pattern,
        f"{name}.include.spdlog.details": pattern,
        f"{name}.include.spdlog.fmt": pattern,
        f"{name}.include.spdlog.fmt.bundled": pattern,
        f"{name}.include.spdlog.sinks": pattern,
        f"{name}.include.taskflow": pattern,
        f"{name}.include.taskflow.algorithm": pattern,
        f"{name}.include.taskflow.core": pattern,
        f"{name}.include.taskflow.cuda": pattern,
        f"{name}.include.taskflow.cuda.algorithm": pattern,
        f"{name}.include.taskflow.dsl": pattern,
        f"{name}.include.taskflow.sycl": pattern,
        f"{name}.include.taskflow.sycl.algorithm": pattern,
        f"{name}.include.taskflow.utility": pattern,
        f"{name}.include.tl": pattern,
        f"{name}.include.tsl": pattern,
    },
)
